@@ -6,7 +6,7 @@ my @classes = classes_from_files(['lib/HackaMol.pm',glob('lib/HackaMol/*.pm')],'
 my $painter = UML::Class::Simple->new(\@classes);
 $painter->inherited_methods(0);
 
-$painter->as_png('shit.png');
+$painter->as_png('stuff.png');
 
 #print Dumper $painter->as_dom();
 
