@@ -16,7 +16,7 @@ print Dumper $info;
 say scalar(@$mols);
 printf ("parse time: %10.6f\n", $t2 - $t1);
 
-open my $fh2, ">", 'shit.xyz';
+open my $fh2, ">", 'stuff.xyz';
 
 foreach my $mol (@$mols){
     $mol->print_xyz($fh2);
